@@ -70,6 +70,10 @@ for each processing instruction and still produce output with no line
 breaks. If you want to output a line break after a processing
 instruction, put a blank line immediately after it.
 
+Processing instructions can be split across lines to improve
+readability. Split lines are joined together before processing, after
+removing any trailing newline characters.
+
 ``##``
 ^^^^^^
 
@@ -295,6 +299,7 @@ __usage__ = """
 __doc__ %= __usage__
 __usage__ = __doc__.split('\n')[0] + __usage__
 
+from ast import literal_eval
 import codecs
 from datetime import datetime, timedelta
 import getopt
@@ -392,8 +397,8 @@ class Template(object):
         rain_hour = self.computations.rain_hour
         rain_day = self.computations.rain_day
         rain_24hr = self.computations.rain_24hr
-        pressure_offset = eval(self.params.get('config', 'pressure offset'))
-        fixed_block = eval(self.status.get('fixed', 'fixed block'))
+        pressure_offset = float(self.params.get('config', 'pressure offset'))
+        fixed_block = literal_eval(self.status.get('fixed', 'fixed block'))
         # start off with no time rounding
         round_time = None
         # start off in hourly data mode
@@ -414,26 +419,32 @@ class Template(object):
         else:
             tmplt = open(template_file, 'rb')
         # do the text processing
+        line = ''
         while True:
-            line = tmplt.readline()
-            if not line:
+            new_line = tmplt.readline()
+            if not new_line:
                 break
-            if isinstance(line, bytes) or sys.version_info[0] < 3:
-                line = line.decode(file_encoding)
+            if isinstance(new_line, bytes) or sys.version_info[0] < 3:
+                new_line = new_line.decode(file_encoding)
+            line += new_line
             parts = line.split('#')
-            for i in range(len(parts)):
+            if len(parts) % 2 == 0:
+                # odd number of '#'
+                line = line.rstrip('\r\n')
+                continue
+            for i, part in enumerate(parts):
                 if i % 2 == 0:
                     # not a processing directive
-                    if i == 0 or parts[i] != '\n':
-                        yield parts[i]
+                    if i == 0 or part != '\n':
+                        yield part
                     continue
-                if parts[i] and parts[i][0] == '!':
+                if part and part[0] == '!':
                     # comment
                     continue
                 # Python 2 shlex can't handle unicode
                 if sys.version_info[0] < 3:
-                    parts[i] = parts[i].encode(file_encoding)
-                command = shlex.split(parts[i])
+                    part = part.encode(file_encoding)
+                command = shlex.split(part)
                 if sys.version_info[0] < 3:
                     command = map(lambda x: x.decode(file_encoding), command)
                 if command == []:
@@ -504,7 +515,7 @@ class Template(object):
                     data = data_set[idx]
                 elif command[0] == 'live':
                     data_set = self.calib_data
-                    idx = datetime.max
+                    idx = live_data['idx']
                     valid_data = True
                     data = live_data
                 elif command[0] == 'timezone':
@@ -558,9 +569,9 @@ class Template(object):
                     if valid_data and loop_count > 0:
                         tmplt.seek(loop_start, 0)
                 else:
-                    logger.error(
-                        "Unknown processing directive: #%s#", parts[i])
+                    logger.error("Unknown processing directive: #%s#", part)
                     return
+            line = ''
 
     def make_text(self, template_file, live_data=None):
         result = u''
